==> qmmp-0.9.2-1.00.tar.gz: qmmp-0.9.2/src/plugins/General/converter/translations/converter_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>Converter</name>
    <message>
        <location filename="../converter.cpp" line="169"/>
        <source>Track: %1</source>
        <translation>トラック: %1</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="171"/>
        <source>Preset: %1</source>
        <translation>プリセット: %1</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="266"/>
        <source>Encoding...</source>
        <translation>符号化しています...</translation>
    </message>
</context>
<context>
    <name>ConverterDialog</name>
    <message>
        <location filename="../converterdialog.ui" line="14"/>
        <source>Converter Settings</source>
        <translation>転換設定</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="29"/>
        <source>Select tracks to convert:</source>
        <translation>転換したいトラックを選択:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="43"/>
        <source>Output directory:</source>
        <translation>出力先ディレクトリ:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="53"/>
        <source>Output file name:</source>
        <translation>出力ファイルの名前:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="63"/>
        <source>Preset:</source>
        <translation>プリセット:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="73"/>
        <source>Overwrite existing files</source>
        <translation>既存のファイルを上書き</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="90"/>
        <source>Choose a directory</source>
        <translation>ディレクトリを選択</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="110"/>
        <source>Artist</source>
        <translation>アーティスト</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="111"/>
        <source>Album</source>
        <translation>アルバム</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="112"/>
        <source>Album Artist</source>
        <translation>アルバムアーティスト</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="113"/>
        <source>Title</source>
        <translation>タイトル</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="114"/>
        <source>Track Number</source>
        <translation>トラック番号</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="115"/>
        <source>Two-digit Track Number</source>
        <translation>トラック番号 数字2桁</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="120"/>
        <source>Disc Number</source>
        <translation>ディスク番号</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="121"/>
        <source>File Name</source>
        <translation>ファイル名</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="122"/>
        <source>File Path</source>
        <translation>ファイルパス</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="116"/>
        <source>Genre</source>
        <translation>ジャンル</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="117"/>
        <source>Comment</source>
        <translation>コメント</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="118"/>
        <source>Composer</source>
        <translation>作曲者</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="119"/>
        <source>Duration</source>
        <translation>演奏時間</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="123"/>
        <source>Year</source>
        <translation>年</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="124"/>
        <source>Condition</source>
        <translation>定番</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="130"/>
        <source>Create</source>
        <translation>作成</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="131"/>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="132"/>
        <source>Create a Copy</source>
        <translation>複製を作成</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="133"/>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
</context>
<context>
    <name>ConverterFactory</name>
    <message>
        <location filename="../converterfactory.cpp" line="28"/>
        <source>Converter Plugin</source>
        <translation>ファイル形式転換プラグイン</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="49"/>
        <source>About Converter Plugin</source>
        <translation>転換プラグインについて</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="50"/>
        <source>Qmmp Converter Plugin</source>
        <translation>QMMP 転換プラグイン</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="51"/>
        <source>This plugin converts supported audio files to other file formats using external command-line encoders</source>
        <translation>このプラグインは外部のコマンドライン方式のエンコーダーを利用してサポート対象形式間で音声ファイルを転換し別の音声ファイルを生成します。</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>ConverterHelper</name>
    <message>
        <location filename="../converterhelper.cpp" line="35"/>
        <source>Convert</source>
        <translation>転換</translation>
    </message>
    <message>
        <location filename="../converterhelper.cpp" line="36"/>
        <source>Meta+C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterhelper.cpp" line="42"/>
        <source>Converting...</source>
        <translation>転換しています</translation>
    </message>
    <message>
        <location filename="../converterhelper.cpp" line="43"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
</context>
<context>
    <name>PresetEditor</name>
    <message>
        <location filename="../preseteditor.ui" line="14"/>
        <source>Preset Editor</source>
        <translation>プリセットエディター</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="29"/>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="35"/>
        <source>Name:</source>
        <translation>名前:</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="45"/>
        <source>Extension:</source>
        <translation>拡張:</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="58"/>
        <source>Command</source>
        <translation>コマンド</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="77"/>
        <source>Options</source>
        <translation>オプション</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="83"/>
        <source>Write tags</source>
        <translation>タグを書き込む</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="90"/>
        <source>Convert to 16 bit</source>
        <translation>16ビットに変換</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="37"/>
        <source>%1 (Read Only)</source>
        <translation>%1 (読み込み専用)</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="70"/>
        <source>Output file</source>
        <translation>出力ファイル</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="71"/>
        <source>Input file</source>
        <translation>入力ファイル</translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/plugins/General/converter/translations/converter_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>Converter</name>
    <message>
        <location filename="../converter.cpp" line="130"/>
        <location filename="../converter.cpp" line="230"/>
        <source>Cancelled</source>
        <translation>中止しました</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="145"/>
        <location filename="../converter.cpp" line="212"/>
        <source>Error</source>
        <translation>エラーです</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="177"/>
        <source>Converting</source>
        <translation>転換しています</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="241"/>
        <source>Encoding</source>
        <translation>符号化しています</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="279"/>
        <source>Finished</source>
        <translation>完了しました</translation>
    </message>
</context>
<context>
    <name>ConverterDialog</name>
    <message>
        <location filename="../converterdialog.ui" line="14"/>
        <source>Audio Converter</source>
        <translation>音響転換</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="44"/>
        <source>Progress</source>
        <translation>進捗</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="49"/>
        <source>State</source>
        <translation>状況</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="63"/>
        <source>Output directory:</source>
        <translation>出力先ディレクトリ:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="80"/>
        <source>Output file name:</source>
        <translation>出力ファイルの名前:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="97"/>
        <source>Preset:</source>
        <translation>プリセット:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="114"/>
        <source>Overwrite existing files</source>
        <translation>既存のファイルを上書き</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="124"/>
        <source>Convert</source>
        <translation>転換</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="131"/>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="107"/>
        <source>Choose a directory</source>
        <translation>ディレクトリを選択</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="190"/>
        <source>Artist</source>
        <translation>アーティスト</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="191"/>
        <source>Album</source>
        <translation>アルバム</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="192"/>
        <source>Album Artist</source>
        <translation>アルバムアーティスト</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="39"/>
        <location filename="../converterdialog.cpp" line="193"/>
        <source>Title</source>
        <translation>タイトル</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="194"/>
        <source>Track Number</source>
        <translation>トラック番号</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="195"/>
        <source>Two-digit Track Number</source>
        <translation>トラック番号 数字2桁</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="200"/>
        <source>Disc Number</source>
        <translation>ディスク番号</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="201"/>
        <source>File Name</source>
        <translation>ファイル名</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="202"/>
        <source>File Path</source>
        <translation>ファイルパス</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="196"/>
        <source>Genre</source>
        <translation>ジャンル</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="128"/>
        <location filename="../converterdialog.cpp" line="367"/>
        <location filename="../converterdialog.cpp" line="373"/>
        <source>Error</source>
        <translation>エラーです</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="133"/>
        <source>Waiting</source>
        <translation>待機中です</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="197"/>
        <source>Comment</source>
        <translation>コメント</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="198"/>
        <source>Composer</source>
        <translation>作曲者</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="199"/>
        <source>Duration</source>
        <translation>演奏時間</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="203"/>
        <source>Year</source>
        <translation>年</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="204"/>
        <source>Condition</source>
        <translation>定番</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="210"/>
        <source>Create</source>
        <translation>作成</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="211"/>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="212"/>
        <source>Create a Copy</source>
        <translation>複製を作成</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="213"/>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="367"/>
        <source>Unable to execute &quot;%1&quot;. Program not found.</source>
        <translation>&quot;%1&quot; を実行できません。プログラムがみつかりません。</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="373"/>
        <source>Process &quot;%1&quot; finished with error.</source>
        <translation>プロセス &quot;%1&quot; がエラーで終了しました。</translation>
    </message>
</context>
<context>
    <name>ConverterFactory</name>
    <message>
        <location filename="../converterfactory.cpp" line="30"/>
        <source>Converter Plugin</source>
        <translation>ファイル形式転換プラグイン</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="51"/>
        <source>About Converter Plugin</source>
        <translation>転換プラグインについて</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="52"/>
        <source>Qmmp Converter Plugin</source>
        <translation>QMMP 転換プラグイン</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="53"/>
        <source>This plugin converts supported audio files to other file formats using external command-line encoders</source>
        <translation>このプラグインは外部のコマンドライン方式のエンコーダーを利用してサポート対象形式間で音声ファイルを転換し別の音声ファイルを生成します。</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="55"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>ConverterHelper</name>
    <message>
        <location filename="../converterhelper.cpp" line="33"/>
        <source>Convert</source>
        <translation>転換</translation>
    </message>
    <message>
        <location filename="../converterhelper.cpp" line="34"/>
        <source>Meta+C</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PresetEditor</name>
    <message>
        <location filename="../preseteditor.ui" line="14"/>
        <source>Preset Editor</source>
        <translation>プリセットエディター</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="29"/>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="35"/>
        <source>Name:</source>
        <translation>名前:</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="45"/>
        <source>Extension:</source>
        <translation>拡張:</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="58"/>
        <source>Command</source>
        <translation>コマンド</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="77"/>
        <source>Options</source>
        <translation>オプション</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="83"/>
        <source>Write tags</source>
        <translation>タグを書き込む</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="90"/>
        <source>Convert to 16 bit</source>
        <translation>16ビットに変換</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="37"/>
        <source>%1 (Read Only)</source>
        <translation>%1 (読み込み専用)</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="70"/>
        <source>Output file</source>
        <translation>出力ファイル</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="71"/>
        <source>Input file</source>
        <translation>入力ファイル</translation>
    </message>
</context>
</TS>
